decode_to_string

Function decode_to_string 

pub fn decode_to_string(b32: &str) -> Result<String>
Decodes a Base32 string without padding into a string using the specified decoding method.

Parameters

  • b32: A string containing the encoded Base32 data without padding.

Returns

A result containing a string if decoding is successful and the data is valid UTF-8, or an error.