decode_to_string

Function decode_to_string 

pub fn decode_to_string(value: &str, encoding: Encoding) -> Result<String>
Decodes a BaseX string into a string using the specified decoding method.

Parameters

  • value: A string containing the encoded BaseX data.
  • encoding: The BaseX decoding method to be used.

Returns

A result containing a string if decoding is successful and the data is valid UTF-8, or an error.